@@ -1,5 +1,5 @@
 # SPDX-License-Identifier: Apache-2.0
-# Copyright © 2021 Wrangle Ltd
+# Copyright © 2022 Wrangle Ltd
 
 from wrgl.config import Config, User, Remote, Branch, Receive, Auth, Pack
 from wrgl.commit import Commit, CommitResult, CommitTree, Table
@@ -7,8 +7,18 @@ from wrgl.diff import DiffResult, RowDiff
 from wrgl.repository import Repository
 
 __all__ = [
-    "Config", "User", "Remote", "Branch", "Receive", "Auth", "Pack",
-    "Commit", "CommitResult", "CommitTree", "Table",
-    "DiffResult", "RowDiff",
+    "Config",
+    "User",
+    "Remote",
+    "Branch",
+    "Receive",
+    "Auth",
+    "Pack",
+    "Commit",
+    "CommitResult",
+    "CommitTree",
+    "Table",
+    "DiffResult",
+    "RowDiff",
     "Repository",
 ]
